@@ -40,6 +40,7 @@ BASE_CONFIGURATION = {
         "jupyterlab": f"quansight/qhub-jupyterlab:{qhub_image_tag}",
         "dask_worker": f"quansight/qhub-dask-worker:{qhub_image_tag}",
         "dask_gateway": f"quansight/qhub-dask-gateway:{qhub_image_tag}",
+        "conda_store": f"quansight/qhub-conda-store:{qhub_image_tag}",
     },
     "storage": {"conda_store": "60Gi", "shared_filesystem": "100Gi"},
     "theme": {
@@ -119,20 +120,18 @@ DIGITAL_OCEAN = {
 GOOGLE_PLATFORM = {
     "project": "PLACEHOLDER",
     "region": "us-central1",
-    "zone": "us-central1-c",
-    "availability_zones": ["us-central1-c"],
     "kubernetes_version": "1.18.16-gke.502",
     "node_groups": {
         "general": {"instance": "n1-standard-2", "min_nodes": 1, "max_nodes": 1},
-        "user": {"instance": "n1-standard-2", "min_nodes": 0, "max_nodes": 5},
-        "worker": {"instance": "n1-standard-2", "min_nodes": 0, "max_nodes": 5},
+        "user": {"instance": "n1-standard-2", "min_nodes": 1, "max_nodes": 5},
+        "worker": {"instance": "n1-standard-2", "min_nodes": 1, "max_nodes": 5},
     },
 }
 
 AZURE = {
     "project": "PLACEHOLDER",
     "region": "Central US",
-    "kubernetes_version": "1.18.14",
+    "kubernetes_version": "1.18.19",
     "node_groups": {
         "general": {
             "instance": "Standard_D2_v2",
@@ -142,7 +141,7 @@ AZURE = {
         "user": {"instance": "Standard_D2_v2", "min_nodes": 0, "max_nodes": 5},
         "worker": {
             "instance": "Standard_D2_v2",
-            "min_nodes": 0,
+            "min_nodes": 1,
             "max_nodes": 5,
         },
     },
@@ -215,10 +214,8 @@ DEFAULT_ENVIRONMENTS = {
             "python",
             "ipykernel",
             "ipywidgets",
+            "qhub-dask ==0.3.12",
             "python-graphviz",
-            "dask ==2.30.0",
-            "distributed ==2.30.1",
-            "dask-gateway ==0.9.0",
             "numpy",
             "numba",
             "pandas",
@@ -231,6 +228,7 @@ DEFAULT_ENVIRONMENTS = {
             "python",
             "ipykernel",
             "ipywidgets >=7.6",
+            "qhub-dask ==0.3.12",
             "param",
             "python-graphviz",
             "matplotlib >=3.3.4",
@@ -238,7 +236,7 @@ DEFAULT_ENVIRONMENTS = {
             "voila >=0.2.7",
             "streamlit >=0.76",
             "dash >=1.19",
-            "cdsdashboards-singleuser >=0.5.6",
+            "cdsdashboards-singleuser >=0.5.7",
         ],
     },
 }
@@ -261,7 +259,7 @@ def render_config(
     config = BASE_CONFIGURATION
     config["provider"] = cloud_provider
 
-    if ci_provider is not None:
+    if ci_provider is not None and ci_provider != "none":
         config["ci_cd"] = {"type": ci_provider, "branch": "main"}
 
     if terraform_state is not None:
@@ -380,8 +378,6 @@ def render_config(
             "hub_subtitle"
         ] = "Autoscaling Compute Environment on Amazon Web Services"
         config["amazon_web_services"] = AMAZON_WEB_SERVICES
-        if "AWS_DEFAULT_REGION" in os.environ:
-            config["amazon_web_services"]["region"] = os.environ["AWS_DEFAULT_REGION"]
         if kubernetes_version:
             config["amazon_web_services"]["kubernetes_version"] = kubernetes_version
     elif cloud_provider == "local":
@@ -455,7 +451,6 @@ def github_auto_provision(config, owner, repo):
             for name in {
                 "AWS_ACCESS_KEY_ID",
                 "AWS_SECRET_ACCESS_KEY",
-                "AWS_DEFAULT_REGION",
             }:
                 github.update_secret(owner, repo, name, os.environ[name])
         elif config["provider"] == "gcp":
